Geometry.CircularStringZM (Geometry v1.2.0)

A circular-string struct, representing a 3D curve with a measurement.

A non-empty circular-string requires at least three coordinates. In a sequence of arcs the end point of the previous arc is the start point of the next arc, just like the segments of a LineString. This means that a CircularString must have an odd number of points greater than 1.

Summary

Functions

Creates an empty CircularStringZM.

Creates a CircularStringZM from the given Geometry.PointZMs.

Types

t()

@type t() :: %Geometry.CircularStringZM{arcs: Geometry.arcs(), srid: Geometry.srid()}

Functions

new()

@spec new() :: t()

Creates an empty CircularStringZM.

Examples

iex> CircularStringZM.new()
%CircularStringZM{arcs: [], srid: 0}

new(arcs, srid \\ 0)

@spec new([Geometry.PointZM.t()], Geometry.srid()) :: t()

Creates a CircularStringZM from the given Geometry.PointZMs.

Examples

iex> CircularStringZM.new(
...>   [PointZM.new(1, 2, 3, 4), PointZM.new(3, 4, 5, 6), PointZM.new(5, 6, 7, 8)])
%CircularStringZM{arcs: [[1, 2, 3, 4], [3, 4, 5, 6], [5, 6, 7, 8]], srid: 0}